#!/usr/bin/env python
#pylint: skip-file
"""
TopologyApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class TopologyApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getTopologyApplications(self, **kwargs):
        """getTopologyApplications

        Args:


        Returns: TopologyApplicationListResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplications" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyApplicationListResult')
        return responseObject




    def updateTopologyApplication(self, **kwargs):
        """updateTopologyApplications

        Args:

            topologyApplicationDtoList, list[TopologyApplicationDto]: application (required)



        Returns: TaskIdResult
        """

        allParams = ['topologyApplicationDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('topologyApplicationDtoList' in params):
            bodyParam = params['topologyApplicationDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyApplications(self, **kwargs):
        """createTopologyApplications

        Args:

            topologyApplicationDtoList, list[TopologyApplicationDto]: application (required)



        Returns: TaskIdResult
        """

        allParams = ['topologyApplicationDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyApplications" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('topologyApplicationDtoList' in params):
            bodyParam = params['topologyApplicationDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplication(self, **kwargs):
        """getTopologyApplication

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TopologyApplicationResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyApplicationResult')
        return responseObject




    def deleteTopologyApplication(self, **kwargs):
        """deleteTopologyApplication

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPages(self, **kwargs):
        """getTopologyApplicationPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TopologyPageListResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyPageListResult')
        return responseObject




    def updateTopologyPages(self, **kwargs):
        """updateTopologyPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            topologyPageDtoList, list[TopologyPageDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'topologyPageDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)





        if ('topologyPageDtoList' in params):
            bodyParam = params['topologyPageDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyPages(self, **kwargs):
        """createTopologyPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            topologyPageDtoList, list[TopologyPageDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'topologyPageDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)





        if ('topologyPageDtoList' in params):
            bodyParam = params['topologyPageDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPage(self, **kwargs):
        """getTopologyApplicationPage

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TopologyPageResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPage" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyPageResult')
        return responseObject




    def deleteTopologyPage(self, **kwargs):
        """deleteTopologyPage

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyPage" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPageViews(self, **kwargs):
        """getTopologyApplicationPageViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TopologyViewListResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPageViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyViewListResult')
        return responseObject




    def updateTopologyViews(self, **kwargs):
        """updateTopologyViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            topologyViewDtoList, list[TopologyViewDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'topologyViewDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)





        if ('topologyViewDtoList' in params):
            bodyParam = params['topologyViewDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyViews(self, **kwargs):
        """createTopologyViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            topologyViewDtoList, list[TopologyViewDto]: view (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'topologyViewDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)





        if ('topologyViewDtoList' in params):
            bodyParam = params['topologyViewDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPageView(self, **kwargs):
        """getTopologyApplicationPageView

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            viewUuid, str: Topology Application Page View Uuid (required)



        Returns: TopologyViewResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'viewUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPageView" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}/view/{viewUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)

        if ('viewUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['viewUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'viewUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyViewResult')
        return responseObject




    def deleteTopologyView(self, **kwargs):
        """deleteTopologyView

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            viewUuid, str: Topology Application View Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'viewUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyView" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/application/{applicationUuid}/page/{pageUuid}/view/{viewUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)

        if ('viewUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['viewUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'viewUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplications(self, **kwargs):
        """getTopologyApplications

        Args:


        Returns: TopologyApplicationListResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplications" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyApplicationListResult')
        return responseObject




    def updateTopologyApplication(self, **kwargs):
        """updateTopologyApplications

        Args:

            topologyApplicationDtoList, list[TopologyApplicationDto]: application (required)



        Returns: TaskIdResult
        """

        allParams = ['topologyApplicationDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('topologyApplicationDtoList' in params):
            bodyParam = params['topologyApplicationDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyApplications(self, **kwargs):
        """createTopologyApplications

        Args:

            topologyApplicationDtoList, list[TopologyApplicationDto]: application (required)



        Returns: TaskIdResult
        """

        allParams = ['topologyApplicationDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyApplications" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('topologyApplicationDtoList' in params):
            bodyParam = params['topologyApplicationDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplication(self, **kwargs):
        """getTopologyApplication

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TopologyApplicationResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyApplicationResult')
        return responseObject




    def deleteTopologyApplication(self, **kwargs):
        """deleteTopologyApplication

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyApplication" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPages(self, **kwargs):
        """getTopologyApplicationPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)



        Returns: TopologyPageListResult
        """

        allParams = ['applicationUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyPageListResult')
        return responseObject




    def updateTopologyPages(self, **kwargs):
        """updateTopologyPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            topologyPageDtoList, list[TopologyPageDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'topologyPageDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)





        if ('topologyPageDtoList' in params):
            bodyParam = params['topologyPageDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyPages(self, **kwargs):
        """createTopologyPages

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            topologyPageDtoList, list[TopologyPageDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'topologyPageDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyPages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)





        if ('topologyPageDtoList' in params):
            bodyParam = params['topologyPageDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPage(self, **kwargs):
        """getTopologyApplicationPage

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TopologyPageResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPage" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyPageResult')
        return responseObject




    def deleteTopologyPage(self, **kwargs):
        """deleteTopologyPage

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyPage" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPageViews(self, **kwargs):
        """getTopologyApplicationPageViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)



        Returns: TopologyViewListResult
        """

        allParams = ['applicationUuid', 'pageUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPageViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyViewListResult')
        return responseObject




    def updateTopologyViews(self, **kwargs):
        """updateTopologyViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            topologyViewDtoList, list[TopologyViewDto]: page (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'topologyViewDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTopologyViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)





        if ('topologyViewDtoList' in params):
            bodyParam = params['topologyViewDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def createTopologyViews(self, **kwargs):
        """createTopologyViews

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            topologyViewDtoList, list[TopologyViewDto]: view (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'topologyViewDtoList']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method createTopologyViews" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}/view'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)





        if ('topologyViewDtoList' in params):
            bodyParam = params['topologyViewDtoList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTopologyApplicationPageView(self, **kwargs):
        """getTopologyApplicationPageView

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            viewUuid, str: Topology Application Page View Uuid (required)



        Returns: TopologyViewResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'viewUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTopologyApplicationPageView" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}/view/{viewUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)

        if ('viewUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['viewUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'viewUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyViewResult')
        return responseObject




    def deleteTopologyView(self, **kwargs):
        """deleteTopologyView

        Args:

            applicationUuid, str: Topology Application Uuid (required)


            pageUuid, str: Topology Application Page Uuid (required)


            viewUuid, str: Topology Application View Uuid (required)



        Returns: TaskIdResult
        """

        allParams = ['applicationUuid', 'pageUuid', 'viewUuid']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTopologyView" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/controllerapp/{applicationUuid}/page/{pageUuid}/view/{viewUuid}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('applicationUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['applicationUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'applicationUuid' + '}',
                                                replacement)

        if ('pageUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['pageUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'pageUuid' + '}',
                                                replacement)

        if ('viewUuid' in params):
            replacement = str(self.apiClient.toPathValue(params['viewUuid']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'viewUuid' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def loadCustomTopology(self, **kwargs):
        """loadCustomTopology

        Args:


        Returns: TopologyResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method loadCustomTopology" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/custom'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyResult')
        return responseObject




    def saveCustomTopology(self, **kwargs):
        """saveCustomTopology

        Args:

            topo, Topology: Topology (required)



        Returns: TaskIdResult
        """

        allParams = ['topo']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method saveCustomTopology" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/custom'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('topo' in params):
            bodyParam = params['topo']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getL2Topology(self, **kwargs):
        """getL2Topology

        Args:

            vlanID, str: ID of VLAN (required)



        Returns: TopologyResult
        """

        allParams = ['vlanID']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getL2Topology" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/l2/{vlanID}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('vlanID' in params):
            replacement = str(self.apiClient.toPathValue(params['vlanID']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'vlanID' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyResult')
        return responseObject




    def getL3TopologyForVrf(self, **kwargs):
        """getL3TopologyForVrf

        Args:

            vrfName, str: VRF Name (required)



        Returns: TopologyResult
        """

        allParams = ['vrfName']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getL3TopologyForVrf" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/l3/vrf/{vrfName}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('vrfName' in params):
            replacement = str(self.apiClient.toPathValue(params['vrfName']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'vrfName' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyResult')
        return responseObject




    def getL3Topology(self, **kwargs):
        """getL3Topology

        Args:

            topologyType, str: Type of topology(OSPF,ISIS,etc) (required)



        Returns: TopologyResult
        """

        allParams = ['topologyType']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getL3Topology" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/l3/{topologyType}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('topologyType' in params):
            replacement = str(self.apiClient.toPathValue(params['topologyType']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'topologyType' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyResult')
        return responseObject




    def getPhysicalTopology(self, **kwargs):
        """getPhysicalTopology

        Args:


        Returns: TopologyResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPhysicalTopology" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/topology/physical-topology'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TopologyResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
TagApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class TagApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getTags(self, **kwargs):
        """Get the tags by filters

        Args:

            resourceType, str: Type of resource (network-device) (required)


            resourceId, str: Resource ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TagDtoListResult
        """

        allParams = ['resourceType', 'resourceId', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTags" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('resourceType' in params):
            queryParams['resourceType'] = self.apiClient.toPathValue(params['resourceType'])

        if ('resourceId' in params):
            queryParams['resourceId'] = self.apiClient.toPathValue(params['resourceId'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TagDtoListResult')
        return responseObject




    def updateTag(self, **kwargs):
        """Update tag to a new value

        Args:

            tagDto, TagDto: TagDto with the new tag (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['tagDto', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateTag" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('tagDto' in params):
            bodyParam = params['tagDto']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addTag(self, **kwargs):
        """Add a new tag

        Args:

            tagDto, TagDto: TagDto with the tag (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['tagDto', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addTag" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('tagDto' in params):
            bodyParam = params['tagDto']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addTagToResource(self, **kwargs):
        """Associate a tag to a resource

        Args:

            tagDto, TagDto: TagDto with tag ID, resource ID and resource type (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['tagDto', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addTagToResource" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag/association'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('tagDto' in params):
            bodyParam = params['tagDto']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def deleteTagFromResource(self, **kwargs):
        """Delete association of tag from a resource

        Args:

            id, str: Tag ID (required)


            resourceType, str: Type of resource. Supported resourceTypes are network-device, interface. (required)


            resourceId, str: Resource ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['id', 'resourceType', 'resourceId', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTagFromResource" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag/association/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('resourceType' in params):
            queryParams['resourceType'] = self.apiClient.toPathValue(params['resourceType'])

        if ('resourceId' in params):
            queryParams['resourceId'] = self.apiClient.toPathValue(params['resourceId'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getTag(self, **kwargs):
        """Retrieves tag by its id

        Args:

            id, str: Tag ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TagDtoResult
        """

        allParams = ['id', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getTag" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TagDtoResult')
        return responseObject




    def deleteTag(self, **kwargs):
        """Delete tag by its id

        Args:

            id, str: Tag ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['id', 'scope']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteTag" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/tag/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
PkibrokerApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class PkibrokerApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getDefaultCaPem(self, **kwargs):
        """getDefaultCaPem

        Args:

            id, str: Certificate ID (required)


            type, str: Certificate type (required)



        Returns:
        """

        allParams = ['id', 'type']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getDefaultCaPem" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate-authority/ca/{id}/{type}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = ''
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)

        if ('type' in params):
            replacement = str(self.apiClient.toPathValue(params['type']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'type' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)





    def legacyUpdateDefaultCaPem(self, **kwargs):
        """updateDefaultCaPem

        Args:

            id, str: Certificate ID (required)


            type, str: Certificate type (required)


            param, TrustpoolUpdateParam: param (required)



        Returns: TrustpoolUpdateStatusResult
        """

        allParams = ['id', 'type', 'param']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method legacyUpdateDefaultCaPem" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate-authority/update/{id}/{type}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = ''
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)

        if ('type' in params):
            replacement = str(self.apiClient.toPathValue(params['type']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'type' + '}',
                                                replacement)





        if ('param' in params):
            bodyParam = params['param']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TrustpoolUpdateStatusResult')
        return responseObject




    def updateDefaultCaPem(self, **kwargs):
        """updateDefaultCaPem

        Args:

            id, str: Certificate ID (required)


            type, str: Certificate type (required)


            param, TrustpoolUpdateParam: param (required)



        Returns: TrustpoolUpdateStatusResult
        """

        allParams = ['id', 'type', 'param']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updateDefaultCaPem" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/certificate-authority/{id}/{type}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = ''
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)

        if ('type' in params):
            replacement = str(self.apiClient.toPathValue(params['type']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'type' + '}',
                                                replacement)





        if ('param' in params):
            bodyParam = params['param']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TrustpoolUpdateStatusResult')
        return responseObject




    def pkiTrustPointListGet(self, **kwargs):
        """pkiTrustPointListGet

        Args:


        Returns: PkiTrustPointListResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointListGet" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PkiTrustPointListResult')
        return responseObject




    def pkiTrustPointPost(self, **kwargs):
        """pkiTrustPointPost

        Args:

            pkiTrustPointInput, PkiTrustPoint: pkiTrustPointInput (required)



        Returns: TaskIdResult
        """

        allParams = ['pkiTrustPointInput']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointPost" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('pkiTrustPointInput' in params):
            bodyParam = params['pkiTrustPointInput']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def pkiTrustPointCount(self, **kwargs):
        """pkiTrustPointListGet

        Args:


        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def pkiTrustPointPkcs12Download(self, **kwargs):
        """pkiTrustPointPkcs12Download

        Args:

            trustPointId, str: Trust-point ID (required)


            token, str: Download token (required)



        Returns:
        """

        allParams = ['trustPointId', 'token']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointPkcs12Download" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/pkcs12/{trustPointId}/{token}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)

        if ('token' in params):
            replacement = str(self.apiClient.toPathValue(params['token']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'token' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)





    def pkiTrustPointGetByDeviceSN(self, **kwargs):
        """pkiTrustPointGetByDeviceSN

        Args:

            serialNumber, str: Device serial-number (required)



        Returns: PkiTrustPointResult
        """

        allParams = ['serialNumber']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointGetByDeviceSN" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/serial-number/{serialNumber}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('serialNumber' in params):
            replacement = str(self.apiClient.toPathValue(params['serialNumber']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'serialNumber' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PkiTrustPointResult')
        return responseObject




    def pkiTrustPointDeleteByDeviceSN(self, **kwargs):
        """pkiTrustPointDeleteByDeviceSN

        Args:

            serialNumber, str: Device serial-number (required)



        Returns: TaskIdResult
        """

        allParams = ['serialNumber']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointDeleteByDeviceSN" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/serial-number/{serialNumber}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('serialNumber' in params):
            replacement = str(self.apiClient.toPathValue(params['serialNumber']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'serialNumber' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def pkiTrustPointListGetByRange(self, **kwargs):
        """getCertificateBriefList

        Args:

            startIndex, int: Index to start returning records from (required)


            recordsToReturn, int: Number of records to return (required)



        Returns: PkiTrustPointListResult
        """

        allParams = ['startIndex', 'recordsToReturn']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointListGetByRange" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{startIndex}/{recordsToReturn}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('startIndex' in params):
            replacement = str(self.apiClient.toPathValue(params['startIndex']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'startIndex' + '}',
                                                replacement)

        if ('recordsToReturn' in params):
            replacement = str(self.apiClient.toPathValue(params['recordsToReturn']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'recordsToReturn' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PkiTrustPointListResult')
        return responseObject




    def pkiTrustPointGet(self, **kwargs):
        """pkiTrustPointGet

        Args:

            trustPointId, str: Trust-point ID (required)



        Returns: PkiTrustPointResult
        """

        allParams = ['trustPointId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointGet" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{trustPointId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PkiTrustPointResult')
        return responseObject




    def pkiTrustPointPush(self, **kwargs):
        """pkiTrustPointPush

        Args:

            trustPointId, str: Trust-point ID (required)



        Returns: TaskIdResult
        """

        allParams = ['trustPointId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointPush" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{trustPointId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def pkiTrustPointDelete(self, **kwargs):
        """pkiTrustPointDelete

        Args:

            trustPointId, str: Trust-point ID (required)



        Returns: TaskIdResult
        """

        allParams = ['trustPointId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointDelete" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{trustPointId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def pkiTrustPointConfigGet(self, **kwargs):
        """pkiTrustPointConfigGet

        Args:

            trustPointId, str: Trust-point ID (required)



        Returns: PkiTrustPointConfigResult
        """

        allParams = ['trustPointId']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method pkiTrustPointConfigGet" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{trustPointId}/config'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'PkiTrustPointConfigResult')
        return responseObject




    def checkPKCS12Downloaded(self, **kwargs):
        """checkPKCS12Downloaded

        Args:

            trustPointId, str: Trust-point ID (required)


            scope, str: Authorization Scope for RBAC (required)


            username, str: requestUsername (required)



        Returns: SuccessResult
        """

        allParams = ['trustPointId', 'scope', 'username']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method checkPKCS12Downloaded" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/trust-point/{trustPointId}/downloaded'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']

        if ('username' in params):
            headerParams['username'] = params['username']



        if ('trustPointId' in params):
            replacement = str(self.apiClient.toPathValue(params['trustPointId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'trustPointId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'SuccessResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class LinkWrapper(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'source': 'str',


            'id': 'str',


            'endPortID': 'str',


            'startPortID': 'str',


            'greyOut': 'bool',


            'linkStatus': 'str',


            'startPortIpv4Address': 'str',


            'startPortIpv4Mask': 'str',


            'endPortIpv4Address': 'str',


            'endPortIpv4Mask': 'str',


            'endPortName': 'str',


            'endPortSpeed': 'str',


            'startPortName': 'str',


            'startPortSpeed': 'str',


            'tag': 'str',


            'target': 'str'

        }

        self.attributeMap = {

            'source': 'source',

            'id': 'id',

            'endPortID': 'endPortID',

            'startPortID': 'startPortID',

            'greyOut': 'greyOut',

            'linkStatus': 'linkStatus',

            'startPortIpv4Address': 'startPortIpv4Address',

            'startPortIpv4Mask': 'startPortIpv4Mask',

            'endPortIpv4Address': 'endPortIpv4Address',

            'endPortIpv4Mask': 'endPortIpv4Mask',

            'endPortName': 'endPortName',

            'endPortSpeed': 'endPortSpeed',

            'startPortName': 'startPortName',

            'startPortSpeed': 'startPortSpeed',

            'tag': 'tag',

            'target': 'target'

        }


        #Device ID correspondng to the source device

        self.source = None # str

        #Unified identifier for device

        self.id = None # str

        #Device port ID corresponding to end devices

        self.endPortID = None # str

        #Device port ID corresponding to start devices

        self.startPortID = None # str

        #Device greyout

        self.greyOut = None # bool

        #Indicates whether link is working

        self.linkStatus = None # str

        #Interface port IPv4 address corresponding to start devices

        self.startPortIpv4Address = None # str

        #Interface port IPv4 mask corresponding to start devices

        self.startPortIpv4Mask = None # str

        #Interface port IPv4 address corresponding to end devices

        self.endPortIpv4Address = None # str

        #Interface port IPv4 mask corresponding to end devices

        self.endPortIpv4Mask = None # str

        #Interface port name corresponding to end devices

        self.endPortName = None # str

        #Interface port speed corresponding to end devices

        self.endPortSpeed = None # str

        #Interface port name corresponding to start devices

        self.startPortName = None # str

        #Interface port speed corresponding to start devices

        self.startPortSpeed = None # str

        #Tag for the devices

        self.tag = None # str

        #Device ID corresponding to the target device

        self.target = None # str




#!/usr/bin/env python
#pylint: skip-file
"""
V2CiscoiseApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class V2CiscoiseApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getList(self, **kwargs):
        """getList

        Args:


        Returns: CiscoIseListResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getList" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CiscoIseListResult')
        return responseObject




    def addCiscoIseConfig(self, **kwargs):
        """add Cisco ISE

        Args:

            ciscoIseDTO, CiscoIseDTO: CiscoIseDTO Object (required)



        Returns: TaskIdResult
        """

        allParams = ['ciscoIseDTO']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addCiscoIseConfig" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'










        if ('ciscoIseDTO' in params):
            bodyParam = params['ciscoIseDTO']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getAuthFileList(self, **kwargs):
        """getList

        Args:


        Returns: IdentityAuthFileInfoListResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAuthFileList" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/auth-file-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'IdentityAuthFileInfoListResult')
        return responseObject




    def addKeystoreFile(self, **kwargs):
        """add Identity Authentication File info

        Args:

            jksFile, file: Authentication File (Java Keystore File) that is needed for communication with the ISE server from APIC-EM controller (required)


            fileType, str: fileType (required)



        Returns: TaskIdResult
        """

        allParams = ['jksFile', 'fileType']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addKeystoreFile" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/auth-file-info'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'multipart/form-data'


        if ('fileType' in params):
            queryParams['fileType'] = self.apiClient.toPathValue(params['fileType'])







        if ('jksFile' in params):
            files['jksFile'] = params['jksFile']




        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getAuthFileCount(self, **kwargs):
        """getCount

        Args:


        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getAuthFileCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/auth-file-info/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def deleteAuthFileInfo(self, **kwargs):
        """delete

        Args:

            id, str: Identity Auth File ID (required)



        Returns: TaskIdResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteAuthFileInfo" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/auth-file-info/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getCount(self, **kwargs):
        """getCount

        Args:


        Returns: CountResult
        """

        allParams = []

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'











        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getByIpAddress(self, **kwargs):
        """getByIpAddress

        Args:

            ipAddress, str: CISCO ISE Server IP address (required)



        Returns: CiscoIseResult
        """

        allParams = ['ipAddress']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getByIpAddress" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/ip/{ipAddress}/'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('ipAddress' in params):
            replacement = str(self.apiClient.toPathValue(params['ipAddress']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'ipAddress' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CiscoIseResult')
        return responseObject




    def getEndPointGroupbyId(self, **kwargs):
        """Get Cisco ISE configuration based on id

        Args:

            id, str: id (required)



        Returns: CiscoIseResult
        """

        allParams = ['id']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getEndPointGroupbyId" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/{id}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('id' in params):
            replacement = str(self.apiClient.toPathValue(params['id']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'id' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CiscoIseResult')
        return responseObject




    def delete(self, **kwargs):
        """delete

        Args:

            ipAddress, str: CISCO ISE Server IP address (required)



        Returns: TaskIdResult
        """

        allParams = ['ipAddress']

        params = locals()
        for (key, val) in list(params['kwargs'].items()):
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method delete" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/v2/cisco-ise/{ipAddress}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'






        if ('ipAddress' in params):
            replacement = str(self.apiClient.toPathValue(params['ipAddress']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'ipAddress' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









import sys
from datetime import date
import subprocess

from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass to py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = ['-sv', 'tests']

    def run_tests(self):
        #import here, cause outside the eggs aren't loaded
        import pytest
        errno = pytest.main(self.pytest_args)
        sys.exit(errno)

def get_requirements():
    """ Returns the requirements of libs. """

    with open('requirements.txt', 'r') as f:
        requirements = f.readlines()
    requires = []
    for require in requirements:
        if require.startswith("#") or require.startswith("\n"):
            continue
        else:
            requires.append(require.replace("\n", ""))
    return requires

def get_version():
    """ Returns the version of apic-em.

    Example:
        '1.2.0.x', 1.2.0 is the version number of APIC-EM, and x is the number of pull requests
        since 1.2.0 released.
    """

    with open('__init__.py') as f:
        for line in f.readlines():
            if '__version__' in line:
                apicem_version = line.strip().split("=")[-1].strip(" '")
            if '__first_release_date__' in line:
                first_release_data_str = line.strip().split("=")[-1].strip(" '")
                first_release_data = date(*[int(num) for num in first_release_data_str.split('.')])
                num_commits = get_cr_num(first_release_data)
        return '{apicem_version}.{num_commits}'.format(
            apicem_version=apicem_version, num_commits=num_commits)

    raise ValueError("could not read version")

def get_cr_num(start_date):
    """ Calculate number of PRs since start date.

    Args:
        start_date (datetime.date): Date to calculate CRs number from.

    Returns:
        Number of Crs since start date. (int)
    """

    command = ['git', 'log', '--oneline', '--since="{} 00:00:00"'.format(start_date.isoformat())]
    process = subprocess.Popen(command, stdout=subprocess.PIPE)
    outputs = process.stdout.readlines()
    print("Change log: {}".format(outputs[0]))
    return len(outputs)

def get_packages():
    """ Returns all packages of uniq. """

    packages = find_packages()
    packages = ['{}.{}'.format('uniq', package) for package in packages]
    packages.append('uniq')
    return packages

if __name__ == '__main__':
    with open('README.rst') as file_readme:
        readme = file_readme.read()

    setup(
        name='uniq',
        version=get_version(),
        description="A Python API client library for Cisco's Application Policy "
                    "Infrastructure Controller Enterprise Module (APIC-EM) Northbound APIs.",
        long_description=readme,
        packages=get_packages(),
        package_dir={'uniq': ''},
        install_requires=get_requirements(),
        include_package_data=True,
        tests_require=['pytest'],
        cmdclass={'test': PyTest},
        license='Apache License 2.0',
        platforms=['unix', 'linux', 'osx'],
        author='Amey Patil, Li Feng',
        author_email='ameyspatil@gmail.com, fengli616@gmail.com',
        classifiers=[
            'Development Status :: 5 - Production/Stable',
            'License :: OSI Approved :: Apache Software License',
            'Programming Language :: Python :: 3 :: Only',
            'Programming Language :: Python :: 3.4',
            'Programming Language :: Python :: 3.5',
            'Topic :: Utilities'
        ]
        )



#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class ZtdSiteDevice(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'state': 'str',


            'lastContact': 'str',


            'authStatus': 'DeviceAuthState',


            'deviceId': 'str',


            'lastStateTransitionTime': 'str',


            'stateDisplay': 'str',


            'hostName': 'str',


            'serialNumber': 'str',


            'tag': 'str',


            'id': 'str',


            'platformId': 'str',


            'site': 'str',


            'configId': 'str',


            'bootStrapId': 'str',


            'licenseString': 'str',


            'apCount': 'str',


            'isMobilityController': 'str',


            'pkiEnabled': 'bool',


            'sudiRequired': 'bool',


            'imageId': 'str',


            'connectedToDeviceId': 'str',


            'connectedToPortId': 'str',


            'imagePreference': 'str',


            'configPreference': 'str',


            'connetedToLocationGeoAddr': 'str',


            'connectedToDeviceHostName': 'str',


            'connectedToPortName': 'str',


            'connetedToLocationCivicAddr': 'str',


            # 'attributeInfo': 'object'

            'licenseLevel': 'str',


            'memberCount': 'int',


            'eulaAccepted': 'bool'


        }

        self.attributeMap = {

            'state': 'state',

            'lastContact': 'lastContact',

            'authStatus': 'authStatus',

            'deviceId': 'deviceId',

            'lastStateTransitionTime': 'lastStateTransitionTime',

            'stateDisplay': 'stateDisplay',

            'hostName': 'hostName',

            'serialNumber': 'serialNumber',

            'tag': 'tag',

            'id': 'id',

            'platformId': 'platformId',

            'site': 'site',

            'configId': 'configId',

            'bootStrapId': 'bootStrapId',

            'licenseString': 'licenseString',

            'apCount': 'apCount',

            'isMobilityController': 'isMobilityController',

            'pkiEnabled': 'pkiEnabled',

            'sudiRequired': 'sudiRequired',

            'imageId': 'imageId',

            'connectedToDeviceId': 'connectedToDeviceId',

            'connectedToPortId': 'connectedToPortId',

            'imagePreference': 'imagePreference',

            'configPreference': 'configPreference',

            'connetedToLocationGeoAddr': 'connetedToLocationGeoAddr',

            'connectedToDeviceHostName': 'connectedToDeviceHostName',

            'connectedToPortName': 'connectedToPortName',

            'connetedToLocationCivicAddr': 'connetedToLocationCivicAddr',

            # 'attributeInfo': 'attributeInfo'

            'licenseLevel': 'licenseLevel',

            'memberCount': 'memberCount',

            'eulaAccepted': 'eulaAccepted'

        }



        self.state = None # str


        self.lastContact = None # str


        self.authStatus = None # DeviceAuthState


        self.deviceId = None # str


        self.lastStateTransitionTime = None # str


        self.stateDisplay = None # str

        #Host name

        self.hostName = None # str

        #Serial number

        self.serialNumber = None # str

        #Tag of device

        self.tag = None # str

        #ID of device

        self.id = None # str

        #Platform ID

        self.platformId = None # str

        #Site to which device belongs if auto-provisioned

        self.site = None # str

        #Configuration file id

        self.configId = None # str

        #Bootstrap file id

        self.bootStrapId = None # str

        #License string

        self.licenseString = None # str

        #Wireless AP count

        self.apCount = None # str

        #Specify if device is a wireless mobility controller

        self.isMobilityController = None # str

        #Configure PKCS#12 trust point during PNP workflow if true

        self.pkiEnabled = None # bool


        self.sudiRequired = None # bool

        #Image file ID

        self.imageId = None # str


        self.connectedToDeviceId = None # str


        self.connectedToPortId = None # str


        self.imagePreference = None # str


        self.configPreference = None # str


        self.connetedToLocationGeoAddr = None # str


        self.connectedToDeviceHostName = None # str


        self.connectedToPortName = None # str


        self.connetedToLocationCivicAddr = None # str


        # self.attributeInfo = None # object


        #CLI execution license level
        self.licenseLevel = None # str

        #Count of members in a stack switch excluding master
        self.memberCount = None # int

        #CLI execution EULA accepted or not
        self.eulaAccepted = None # bool



#!/usr/bin/env python
#pylint: skip-file
"""
GlobalcredentialApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class GlobalcredentialApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getGlobalCredential(self, **kwargs):
        """getGlobalCredential

        Args:

            credentialSubType, str: Credential type as CLI / SNMPV2_READ_COMMUNITY / SNMPV2_WRITE_COMMUNITY / SNMPV3 (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: GlobalCredentialListResult
        """

        allParams = ['credentialSubType', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getGlobalCredential" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('credentialSubType' in params):
            queryParams['credentialSubType'] = self.apiClient.toPathValue(params['credentialSubType'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'GlobalCredentialListResult')
        return responseObject




    def addCliCredential(self, **kwargs):
        """addCliCredential

        Args:

            globalCredentialNioList, list[CLICredentialDTO]: globalCredentialNioList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['globalCredentialNioList', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addCliCredential" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential/cli'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('globalCredentialNioList' in params):
            bodyParam = params['globalCredentialNioList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addSnmpReadCommunity(self, **kwargs):
        """addSnmpReadCommunity

        Args:

            globalCredentialNioList, List[SNMPv2ReadCommunityDTO]: globalCredentialNioList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['globalCredentialNioList', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addSnmpReadCommunity" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential/snmpv2-read-community'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('globalCredentialNioList' in params):
            bodyParam = params['globalCredentialNioList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addSnmpWriteCommunity(self, **kwargs):
        """addSnmpWriteCommunity

        Args:

            globalCredentialNioList, List[SNMPv2WriteCommunityDTO]: globalCredentialNioList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['globalCredentialNioList', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addSnmpWriteCommunity" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential/snmpv2-write-community'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('globalCredentialNioList' in params):
            bodyParam = params['globalCredentialNioList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def addSnmpv3Credential(self, **kwargs):
        """addSnmpv3Credential

        Args:

            globalCredentialNioList, List[SNMPv3CredentialDTO]: globalCredentialNioList (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['globalCredentialNioList', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method addSnmpv3Credential" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential/snmpv3'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'POST'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('globalCredentialNioList' in params):
            bodyParam = params['globalCredentialNioList']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def deleteGlobalCredential(self, **kwargs):
        """deleteGlobalCredential

        Args:

            globalCredentialId, str: globalCredentialId (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['globalCredentialId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteGlobalCredential" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/global-credential/{globalCredentialId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('globalCredentialId' in params):
            replacement = str(self.apiClient.toPathValue(params['globalCredentialId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'globalCredentialId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject









#!/usr/bin/env python
#pylint: skip-file
"""
Copyright 2016 Cisco Systems

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

class TrustpoolUpdateStatus(object):



    def __init__(self):
        """
        Attributes:
          swaggerTypes (dict): The key is attribute name and the value is attribute type.
          attributeMap (dict): The key is attribute name and the value is json key in definition.
        """
        self.swaggerTypes = {

            'update': 'str',


            'attributeInfo': 'object',


            'id': 'str'

        }

        self.attributeMap = {

            'update': 'update',

            'attributeInfo': 'attributeInfo',

            'id': 'id'

        }



        self.update = None # str


        self.attributeInfo = None # object


        self.id = None # str




#!/usr/bin/env python
#pylint: skip-file
"""
PnpfileApi.py
    Copyright 2016 Cisco Systems

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

"""
import sys
import os
import urllib.request, urllib.parse, urllib.error

from .models import *


class PnpfileApi(object):

    def __init__(self, apiClient):
      self.apiClient = apiClient



    def getConfigs(self, **kwargs):
        """Retrieves a list of config records

        Args:

            offset, int: Starting index of the response. Minimum value is 1 (required)


            limit, int: Limit the number of responses. Maximum value supported is 500. Minimum value is 1 (required)


            name, str: File name pattern (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: FileObjectListResult
        """

        allParams = ['offset', 'limit', 'name', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getConfigs" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/config'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])

        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'FileObjectListResult')
        return responseObject




    def getConfigCount(self, **kwargs):
        """Returns number of CLI config files

        Args:

            name, str: File name pattern (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['name', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getConfigCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/config/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def deleteConfigById(self, **kwargs):
        """Deletes a configuration with its ID

        Args:

            configId, str: Config ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['configId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deleteConfigById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/config/{configId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('configId' in params):
            replacement = str(self.apiClient.toPathValue(params['configId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'configId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getPnpImageBySearch(self, **kwargs):
        """Retrieves a list of images and the platforms for which they are a default

        Args:

            name, str: Image name (required)


            platform, str: Platform name (required)


            productId, str: Product ID (required)


            match, str: Match all or any parameters (required)


            order, str: Order response in ascending (asc) or descending (des) order of image name. (required)


            offset, int: Starting index of the response. Minimum value is 1 (required)


            limit, int: Limit the number of responses. Maximum value supported is 500. Minimum value is 1 (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdPlatformImageListResult
        """

        allParams = ['name', 'platform', 'productId', 'match', 'order', 'offset', 'limit', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpImageBySearch" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])

        if ('platform' in params):
            queryParams['platform'] = self.apiClient.toPathValue(params['platform'])

        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])

        if ('match' in params):
            queryParams['match'] = self.apiClient.toPathValue(params['match'])

        if ('order' in params):
            queryParams['order'] = self.apiClient.toPathValue(params['order'])

        if ('offset' in params):
            queryParams['offset'] = self.apiClient.toPathValue(params['offset'])

        if ('limit' in params):
            queryParams['limit'] = self.apiClient.toPathValue(params['limit'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdPlatformImageListResult')
        return responseObject




    def updatePnpImageDetails(self, **kwargs):
        """Updates an image and the platforms for which it is default with its ID

        Args:

            image, list[ZtdPlatformImage]: PnP Image (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['image', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method updatePnpImageDetails" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'PUT'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']







        if ('image' in params):
            bodyParam = params['image']


        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getPnpImageBySearchCount(self, **kwargs):
        """Retrieves a count of images

        Args:

            name, str: Image name (required)


            platform, str: Platform name (required)


            productId, str: Product ID (required)


            match, str: Match all or any parameters (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: CountResult
        """

        allParams = ['name', 'platform', 'productId', 'match', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpImageBySearchCount" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/count'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('name' in params):
            queryParams['name'] = self.apiClient.toPathValue(params['name'])

        if ('platform' in params):
            queryParams['platform'] = self.apiClient.toPathValue(params['platform'])

        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])

        if ('match' in params):
            queryParams['match'] = self.apiClient.toPathValue(params['match'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'CountResult')
        return responseObject




    def getPnpDefaultImages(self, **kwargs):
        """Retrieves the default image for a given platform or product ID

        Args:

            platform, str: Platform name. Provide either platform name or product ID (required)


            productId, str: Product ID. Provide either platform name or product ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdDefaultImageListResult
        """

        allParams = ['platform', 'productId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpDefaultImages" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/default'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('platform' in params):
            queryParams['platform'] = self.apiClient.toPathValue(params['platform'])

        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdDefaultImageListResult')
        return responseObject




    def getPnpValidImageExtensions(self, **kwargs):
        """Retrieves the valid image extensions supported

        Args:

            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdValidExtensionsResult
        """

        allParams = ['scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpValidImageExtensions" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/valid-extension'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdValidExtensionsResult')
        return responseObject




    def getPnpImageById(self, **kwargs):
        """Retrieves an image and the platforms for which it is a default with its ID

        Args:

            imageId, str: Image ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdPlatformImageResult
        """

        allParams = ['imageId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpImageById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/{imageId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('imageId' in params):
            replacement = str(self.apiClient.toPathValue(params['imageId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'imageId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdPlatformImageResult')
        return responseObject




    def deletePnpImageById(self, **kwargs):
        """Deletes an image and default platform assiciations with its ID

        Args:

            imageId, str: Image ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: TaskIdResult
        """

        allParams = ['imageId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method deletePnpImageById" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/{imageId}'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'DELETE'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'




        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('imageId' in params):
            replacement = str(self.apiClient.toPathValue(params['imageId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'imageId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'TaskIdResult')
        return responseObject




    def getPnpRecommendedPlatform(self, **kwargs):
        """Retrieves the recommended platforms for a given image

        Args:

            imageId, str: Image ID (required)


            productId, str: Product ID (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdPlatformListResult
        """

        allParams = ['imageId', 'productId', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpRecommendedPlatform" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/image/{imageId}/recommended-platform'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('productId' in params):
            queryParams['productId'] = self.apiClient.toPathValue(params['productId'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']



        if ('imageId' in params):
            replacement = str(self.apiClient.toPathValue(params['imageId']))
            replacement = urllib.parse.quote(replacement)
            resourcePath = resourcePath.replace('{' + 'imageId' + '}',
                                                replacement)






        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdPlatformListResult')
        return responseObject




    def getPnpPlatforms(self, **kwargs):
        """Retrieves a list of platforms

        Args:

            platformName, str: Platform name (required)


            scope, str: Authorization Scope for RBAC (required)



        Returns: ZtdPlatformListResult
        """

        allParams = ['platformName', 'scope']

        params = locals()
        for (key, val) in params['kwargs'].items():
            if key not in allParams:
                raise TypeError("Got an unexpected keyword argument '%s' to method getPnpPlatforms" % key)
            params[key] = val
        del params['kwargs']

        resourcePath = '/pnp-file/platform'
        resourcePath = resourcePath.replace('{format}', 'json')
        method = 'GET'

        queryParams = {}
        headerParams = {}
        formParams = {}
        files = {}
        bodyParam = None

        headerParams['Accept'] = 'application/json'
        headerParams['Content-Type'] = 'application/json'


        if ('platformName' in params):
            queryParams['platformName'] = self.apiClient.toPathValue(params['platformName'])



        if ('scope' in params):
            headerParams['scope'] = params['scope']








        postData = (formParams if formParams else bodyParam)

        response = self.apiClient.callAPI(resourcePath, method, queryParams,
                                          postData, headerParams, files=files)


        if not response:
            return None

        responseObject = self.apiClient.deserialize(response, 'ZtdPlatformListResult')
        return responseObject









class DifferentAttr(object):
    def __init__(self):
        self.swaggerTypes = {
            'id': 'str',
            'alias': 'str' # in faked_client is name
        }

        self.attributeMap = {
            'id': 'id',
            'alias': 'name'
        }

        self.id = None
        self.alias = None
